# MirageML Python Library

The MirageML Python Library provides a convenient interface to run AI in the terminal using your files or web documentation as context.

## Installation

This requires Python 3.9 or later. Install the package with:

```
pip install -U mirageml
```

## Support
Send an email to [support@mirageml.com](mailto:support@mirageml.com) for support.